@@ -1,14 +1,14 @@
 package App::GhostWork;
 ######################################################################
 #
-# App::GhostWork - Barcode Logger(When,Where,Who,What,toWhich,Why)
+# App::GhostWork - Barcode Logger(When,Where,Who,What,toWhich,Why,Howmanysec)
 #
 # https://metacpan.org/dist/App-GhostWork
 #
 # Copyright (c) 2021 INABA Hitoshi <ina@cpan.org> in a CPAN
 ######################################################################
 
-$VERSION = '0.02';
+$VERSION = '0.03';
 $VERSION = $VERSION;
 
 use 5.00503;
@@ -23,7 +23,7 @@ __END__
 
 =head1 NAME
 
-App::GhostWork - Barcode Logger(When,Where,Who,What,toWhich,Why)
+App::GhostWork - Barcode Logger(When,Where,Who,What,toWhich,Why,Howmanysec)
 
 =head1 SYNOPSIS
 
@@ -38,18 +38,19 @@ App::GhostWork - Barcode Logger(When,Where,Who,What,toWhich,Why)
 This software creates a log file from barcode data. The log file is in
 LTSV format. Each record has the following labels.
 
-  -----------------------------------------------------
-  labels:     meanings
-  -----------------------------------------------------
-  csv:        All columns as CSV format
-  when:       When barcode was read ?
-  where:      Where barcode was read ? (COMPUTERNAME)
-  who:        Who read the barcode ?
-  what:       What barcode read ?
-  towhich:    Which status after barcode was read ?
-  why:        Why become its status ? (optional)
-  looseid:    Moderately unique random numbers
-  -----------------------------------------------------
+  --------------------------------------------------------
+  label:         meanings
+  --------------------------------------------------------
+  csv:           All columns by CSV format
+  when_:         When barcode was read ?
+  where_:        Where barcode was read ? (COMPUTERNAME)
+  who:           Who read the barcode ?
+  what:          What barcode read ?
+  towhich:       Which status after barcode was read ?
+  why:           Why become its status ? (optional)
+  howmanysec:    How many seconds to make this record
+  looseid:       Moderately unique random numbers
+  --------------------------------------------------------
 
 =head2 Command File Name
 
@@ -76,13 +77,6 @@ LTSV format. Each record has the following labels.
   LOG/when/towhich/when-towhich-who.ltsv
   -----------------------------------------------------
 
-=head2 ***REMOVE_THIS_TIMESTAMP***
-
-Working time per record can be calculated by comparing the "WHEN" of
-adjacent records. The next record after the final work contains string
-"***REMOVE_THIS_TIMESTAMP***" as "WHAT". If you want only barcode
-records, you need to remove those records.
-
 =head1 AUTHOR
 
 INABA Hitoshi E<lt>ina@cpan.orgE<gt> in a CPAN
